"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const fs = require("fs-extra");
const os = require("os");
const lisk_sdk_1 = require("lisk-sdk");
const defaultDir = '.lisk';
const defaultFolder = 'lisk-core';
const getConfigPath = (dataPath) => path.join(dataPath, 'config');
exports.getDefaultPath = () => path.join(os.homedir(), defaultDir, defaultFolder);
exports.getFullPath = (dataPath) => path.resolve(dataPath);
exports.splitPath = (dataPath) => {
    const rootPath = path.resolve(path.join(dataPath, '../'));
    const label = path.parse(dataPath).name;
    return {
        rootPath,
        label,
    };
};
exports.getDefaultConfigDir = () => path.join(__dirname, '../..');
exports.getNetworkConfigFilesPath = (dataPath, network) => {
    const basePath = path.join(dataPath, 'config', network);
    return {
        genesisBlockFilePath: path.join(basePath, 'genesis_block.json'),
        configFilePath: path.join(basePath, 'config.json'),
    };
};
exports.getDefaultNetworkConfigFilesPath = (network) => {
    const basePath = path.join(exports.getDefaultConfigDir(), 'config', network);
    return {
        genesisBlockFilePath: path.join(basePath, 'genesis_block.json'),
        configFilePath: path.join(basePath, 'config.json'),
    };
};
exports.getConfigDirs = (dataPath) => {
    const configPath = getConfigPath(dataPath);
    fs.ensureDirSync(configPath);
    const files = fs.readdirSync(configPath);
    return files.filter(file => fs.statSync(path.join(configPath, file)).isDirectory());
};
exports.getGenesisBlockAndConfig = async (network) => {
    const { genesisBlockFilePath: defaultGenesisBlockFilePath, configFilePath: defaultConfigFilepath, } = exports.getDefaultNetworkConfigFilesPath(network);
    const genesisBlock = await fs.readJSON(defaultGenesisBlockFilePath);
    const config = await fs.readJSON(defaultConfigFilepath);
    return { genesisBlock, config };
};
exports.removeConfigDir = (dataPath, network) => fs.removeSync(path.join(dataPath, 'config', network));
exports.ensureConfigDir = (dataPath, network) => fs.ensureDirSync(path.join(dataPath, 'config', network));
exports.getBlockchainDBPath = (dataPath) => path.join(dataPath, 'data', 'blockchain.db');
exports.getForgerDBPath = (dataPath) => path.join(dataPath, 'data', 'forger.db');
exports.getPidPath = (dataPath) => path.join(dataPath, 'tmp', 'pids', 'controller.pid');
exports.getSocketsPath = (dataPath, network = defaultFolder) => {
    const dirs = lisk_sdk_1.systemDirs(network, dataPath);
    return {
        root: `unix://${dirs.sockets}`,
        pub: `unix://${dirs.sockets}/lisk_pub.sock`,
        sub: `unix://${dirs.sockets}/lisk_sub.sock`,
        rpc: `unix://${dirs.sockets}/bus_rpc_socket.sock`,
    };
};
//# sourceMappingURL=path.js.map